@@ -63,28 +63,28 @@ var NAVTREEINDEX =
 [
 "alloc_8h.html",
 "group__pw__client.html#gaf334e712707cd3d4fb97100f3baedeb0",
-"group__pw__global.html#ga7c5ab037320ab252af6eb6eb1b85b0b9",
-"group__pw__keys.html#ga920ad1d3f16b5fe42e001aab2af08680",
-"group__pw__node.html#ga125b3c8bae9656635dd9c24febbe221f",
-"group__pw__session__manager.html#ga0a2fbf1e9c6493db2e61e629647dda82",
-"group__pw__work__queue.html#ga528c2be5bb8ef21bdbe8bfa44485f8bb",
-"group__spa__cpu.html#gaab2a78075bf054d09f7e950150278b8b",
-"group__spa__json.html#ga0d0d13b703fb3bf42b6a96b11973767a",
-"group__spa__names.html#ga9d31cf5ef1e43bb2f1aca6b3dd07a0fa",
-"group__spa__param.html#ga34f2853a6e1fb9c8600cd3675f48376e",
-"group__spa__param.html#gga15af911097602fc40039042f4d542e87a3979d9964045fd48c076dc1f83951119",
-"group__spa__param.html#gga8aac121d9e3a588a30d970526fd556dda124cfca5319dc552b3364f1d4ddce452",
-"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea7928095dd38a36fbf6819d61199cf5e2",
-"group__spa__pod.html#ga9c600d17cc240567be847b7f5f586bee",
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635ab0d0e30c07c9d934c96bc2210183537b",
-"page_module_avb.html",
-"page_spa_pod.html#autotoc_md255",
-"structpw__core__methods.html#af1831e5a0a805bf3ed47e48dbd09ee3a",
-"structpw__memblock.html#a8e96a2d24a5fc723b2a637de4bf700b1",
-"structspa__audio__aec__methods.html#a73977fea4b6c069260af4f16b08ceee0",
-"structspa__hook.html",
-"structspa__pod__bitmap.html",
-"tutorial4_8c-example.html"
+"group__pw__global.html#ga5a70a0e4be433825f0e5baf7277c0e7e",
+"group__pw__keys.html#ga8226b0005fed53b77740e919947f6e60",
+"group__pw__module.html#gad670c8d581f68d016f475c12cff250c8",
+"group__pw__resource.html#gafc12935cd9ee93e992cae1e2910e6f04",
+"group__pw__utils.html#ga8869815cdd42998571019730afd248ff",
+"group__spa__cpu.html#ga863ee498bc3630a98ee12fe569a9dc30",
+"group__spa__interfaces.html#ga6492da0e834e92dbbcef7dd3026ce04f",
+"group__spa__names.html#ga4ca9373715177f903a0014796b1d8821",
+"group__spa__param.html#ga304470cf722efd8b2b0617268235c322",
+"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586add5a25402d5f44adde274c95091135d2",
+"group__spa__param.html#gga741ca54fc7f93308779660120bbed31eaa5d835e17315a1ed31a73323da1fa02a",
+"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea43dce82d44b02558ba417caccf9395da",
+"group__spa__pod.html#ga9382aceb62c82555c3e3223fa0da4d16",
+"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a6b256812f3b819d23d240f76d70e2dbf",
+"page_midi.html#autotoc_md21",
+"page_spa_plugins.html#autotoc_md234",
+"structpw__core__events.html#a8a700a03453729d52d96112647125303",
+"structpw__link__info.html#a5a21130d91e20dafc4ce1b09b7c30aca",
+"structpw__time.html#ad817da21bea1591d70f837c251a73468",
+"structspa__graph__node.html#ada29bc9109cd890c74cfba630989b76c",
+"structspa__node__methods.html#a788f398e8fa5e85f03ecb68602821204",
+"structspa__video__info__dsp.html#ada698c22ed974fa690ff6ee37855e659"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
