@@ -1,5 +1,23 @@
 var NAVTREEINDEX17 =
 {
+"page_spa_plugins.html#autotoc_md234":[9,5,7],
+"page_spa_plugins.html#autotoc_md235":[9,5,8],
+"page_spa_plugins.html#autotoc_md236":[9,5,8,0],
+"page_spa_plugins.html#autotoc_md237":[9,5,8,1],
+"page_spa_plugins.html#autotoc_md238":[9,5,9],
+"page_spa_pod.html":[9,6],
+"page_spa_pod.html#autotoc_md243":[9,6,0],
+"page_spa_pod.html#autotoc_md244":[9,6,1],
+"page_spa_pod.html#autotoc_md245":[9,6,1,0],
+"page_spa_pod.html#autotoc_md246":[9,6,1,1],
+"page_spa_pod.html#autotoc_md247":[9,6,1,2],
+"page_spa_pod.html#autotoc_md248":[9,6,1,3],
+"page_spa_pod.html#autotoc_md249":[9,6,1,4],
+"page_spa_pod.html#autotoc_md250":[9,6,2],
+"page_spa_pod.html#autotoc_md251":[9,6,2,0],
+"page_spa_pod.html#autotoc_md252":[9,6,2,1],
+"page_spa_pod.html#autotoc_md253":[9,6,2,2],
+"page_spa_pod.html#autotoc_md254":[9,6,2,3],
 "page_spa_pod.html#autotoc_md255":[9,6,2,4],
 "page_spa_pod.html#autotoc_md256":[9,6,2,5],
 "page_spa_pod.html#autotoc_md257":[9,6,2,6],
@@ -91,10 +109,10 @@ var NAVTREEINDEX17 =
 "route-types_8h.html":[10,8,7,22],
 "route_8h.html":[10,8,7,23],
 "session-manager_8h.html":[10,7,4,0],
-"spa_2examples_2adapter-control_8c-example.html":[13,25],
-"spa_2examples_2example-control_8c-example.html":[13,26],
-"spa_2examples_2local-libcamera_8c-example.html":[13,27],
-"spa_2examples_2local-v4l2_8c-example.html":[13,28],
+"spa_2examples_2adapter-control_8c-example.html":[13,26],
+"spa_2examples_2example-control_8c-example.html":[13,27],
+"spa_2examples_2local-libcamera_8c-example.html":[13,28],
+"spa_2examples_2local-v4l2_8c-example.html":[13,29],
 "spa_2include_2spa_2control_2control_8h.html":[10,8,2,0],
 "spa_2include_2spa_2debug_2context_8h.html":[10,8,3,1],
 "spa_2include_2spa_2debug_2log_8h.html":[10,8,3,4],
@@ -210,10 +228,12 @@ var NAVTREEINDEX17 =
 "structpw__context__events.html":[10,4,2,1],
 "structpw__context__events.html#a15e3c312ad2339ed431059d76fea5a4d":[10,4,2,1,4],
 "structpw__context__events.html#a34b60636aee5925696ca80cbbf63755e":[10,4,2,1,1],
+"structpw__context__events.html#a7ff739c9ebd412efa10756ececc1a27c":[10,4,2,1,7],
 "structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0":[10,4,2,1,5],
 "structpw__context__events.html#a9c874d491dfbdd13eb81c7b0b7561e87":[10,4,2,1,2],
 "structpw__context__events.html#ad0a1b4e42b11a408175ab4f70b1bbc7c":[10,4,2,1,0],
 "structpw__context__events.html#af3303a7f003c10bfbb454c0bbd13360c":[10,4,2,1,3],
+"structpw__context__events.html#af555de72a4d29b3d7c5074aa5e7ab6b0":[10,4,2,1,6],
 "structpw__control.html":[10,5,8,4],
 "structpw__control.html":[10,5,10,2],
 "structpw__control__events.html":[10,5,10,1],
@@ -229,25 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__core__events.html#a590bf80a38429eef4a94d2e8b7f82e56":[10,4,4,2,4],
 "structpw__core__events.html#a7c1f8bd6078afab78aa943704efe7131":[10,4,4,2,7],
 "structpw__core__events.html#a7e1a9d6c8598cee58b622cf61432769e":[10,4,4,2,9],
-"structpw__core__events.html#a8433a5ea5115e8d914a70ba5dacd3b81":[10,4,4,2,1],
-"structpw__core__events.html#a8a700a03453729d52d96112647125303":[10,4,4,2,5],
-"structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7":[10,4,4,2,0],
-"structpw__core__events.html#aab9b9d3a84837d892a4617c29f03e976":[10,4,4,2,6],
-"structpw__core__events.html#acc0442d3b7d94005c8c63e5bd7b89473":[10,4,4,2,2],
-"structpw__core__info.html":[10,4,4,1],
-"structpw__core__info.html#a25d93390dbafcb433827ec29c195404f":[10,4,4,1,5],
-"structpw__core__info.html#a3e394e50023a597dafb391887249d4eb":[10,4,4,1,4],
-"structpw__core__info.html#ab93eadf54d48e19762c4e6ebf5595083":[10,4,4,1,1],
-"structpw__core__info.html#ace1c72a0b6d18567a1156b2d961f63ca":[10,4,4,1,0],
-"structpw__core__info.html#ad294c9fa79558c75141a731c4d812b42":[10,4,4,1,2],
-"structpw__core__info.html#ade7cf9abf36e9cd82fe49ffa95159a2f":[10,4,4,1,3],
-"structpw__core__methods.html":[10,4,4,3],
-"structpw__core__methods.html#a05db653bcc20405f5b6ce5ccbe215703":[10,4,4,3,1],
-"structpw__core__methods.html#a23e319c72a886a40464d74e2e19f27f9":[10,4,4,3,4],
-"structpw__core__methods.html#a460ee1de46fe6e281c576cbe54841309":[10,4,4,3,8],
-"structpw__core__methods.html#a47721985e4d0b24474f5598d0d94b6c5":[10,4,4,3,2],
-"structpw__core__methods.html#a570886edc43416b3dcd10b48016493af":[10,4,4,3,6],
-"structpw__core__methods.html#a7e70c82277387a47a953d64b0ba82cce":[10,4,4,3,7],
-"structpw__core__methods.html#aa5ee0b92d1e85c741adcaa93a04622fa":[10,4,4,3,5],
-"structpw__core__methods.html#ab64487c2ddac4c7d315cc54a4d5b7176":[10,4,4,3,3]
+"structpw__core__events.html#a8433a5ea5115e8d914a70ba5dacd3b81":[10,4,4,2,1]
 };
