@@ -1,11 +1,39 @@
 var NAVTREEINDEX20 =
 {
-"structspa__audio__aec__methods.html#a73977fea4b6c069260af4f16b08ceee0":[11,0,140,10],
-"structspa__audio__aec__methods.html#aa75447be29ace8e48fefb525ed44bcd8":[11,0,140,7],
-"structspa__audio__aec__methods.html#aadf3db584c3062de5a2af134e6d7014d":[11,0,140,3],
-"structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[11,0,140,0],
-"structspa__audio__aec__methods.html#af75957ae10a92bb2253df67aa6eca97f":[11,0,140,9],
-"structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503":[11,0,140,2],
+"structpw__time.html#ad817da21bea1591d70f837c251a73468":[10,0,3,0],
+"structpw__time.html#aebd42745267531bc23e1ee34dd759607":[10,0,3,7],
+"structpw__work__queue.html":[10,5,16,1],
+"structpwtest__context.html":[10,2,2],
+"structpwtest__spa__plugin.html":[10,2,1],
+"structpwtest__spa__plugin.html#a22553184b5d864e926e17d976cffca9f":[10,2,1,2],
+"structpwtest__spa__plugin.html#a8bb79b9b0e5cb045fa2686edde9c3d34":[10,2,1,5],
+"structpwtest__spa__plugin.html#ad517984d1206a29ad28eb83f19f41dbe":[10,2,1,0],
+"structpwtest__spa__plugin.html#adc8a853d256b3dca56a3e805dc96c5b4":[10,2,1,3],
+"structpwtest__spa__plugin.html#ae819473de8479871a6cd78f10a97ce68":[10,2,1,1],
+"structpwtest__spa__plugin.html#aef8a87ec887314f7a70366be56138406":[10,2,1,4],
+"structpwtest__suite.html":[10,2,3],
+"structpwtest__test.html":[10,2,4],
+"structspa__audio__aec.html":[11,0,138],
+"structspa__audio__aec.html#a09e1e6ddb6cba06861e418fad8eb2442":[11,0,138,1],
+"structspa__audio__aec.html#a2c343b0ced8bc8a9d22c441558c1cc9f":[11,0,138,2],
+"structspa__audio__aec.html#a472c09f9a147170d0892a650b60c9b5d":[11,0,138,0],
+"structspa__audio__aec__events.html":[11,0,139],
+"structspa__audio__aec__events.html#a355f3bedb9b4094912577187225797d9":[11,0,139,1],
+"structspa__audio__aec__events.html#ab137f922d3a547caf388c5c11be2e5ce":[11,0,139,0],
+"structspa__audio__aec__info.html":[11,0,140],
+"structspa__audio__aec__info.html#a88dbf8b905a3f808af985764cb21fd7c":[11,0,140,0],
+"structspa__audio__aec__methods.html":[11,0,141],
+"structspa__audio__aec__methods.html#a028adaf84c4fb5c19e416c53874ad57f":[11,0,141,8],
+"structspa__audio__aec__methods.html#a0e357608392e4e4cf8224a523882a80c":[11,0,141,1],
+"structspa__audio__aec__methods.html#a0ea3331fe5e9ceed6a0969c4f2aaa4c3":[11,0,141,4],
+"structspa__audio__aec__methods.html#a1d1c3a7ec1bd783ddb3cea31bc421cb1":[11,0,141,6],
+"structspa__audio__aec__methods.html#a5b18f9a4430576c06bf7067a61a97854":[11,0,141,5],
+"structspa__audio__aec__methods.html#a73977fea4b6c069260af4f16b08ceee0":[11,0,141,10],
+"structspa__audio__aec__methods.html#aa75447be29ace8e48fefb525ed44bcd8":[11,0,141,7],
+"structspa__audio__aec__methods.html#aadf3db584c3062de5a2af134e6d7014d":[11,0,141,3],
+"structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[11,0,141,0],
+"structspa__audio__aec__methods.html#af75957ae10a92bb2253df67aa6eca97f":[11,0,141,9],
+"structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503":[11,0,141,2],
 "structspa__audio__info.html":[10,8,7,34],
 "structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b":[10,8,7,34,5],
 "structspa__audio__info.html#a0c0ba9b2cb3625fdbfa3a5f1a00639d3":[10,8,7,34,16],
@@ -24,21 +52,21 @@ var NAVTREEINDEX20 =
 "structspa__audio__info.html#ab9bbd067632a6e02f042dacff838c89b":[10,8,7,34,9],
 "structspa__audio__info.html#add88e2561d596e2d9d79bf772c7c6972":[10,8,7,34,12],
 "structspa__audio__info.html#ae9fd0fa99badc8be9ce0e59bb75f31f9":[10,8,7,34,13],
-"structspa__audio__info__aac.html":[11,0,142],
-"structspa__audio__info__aac.html#a16974760cfa2cbe91398d01fb7f4b947":[11,0,142,1],
-"structspa__audio__info__aac.html#a3b08334e341344e0035a7ee94a5c87a2":[11,0,142,2],
-"structspa__audio__info__aac.html#ab29a8d8e1cba013ab5008404ba2836ea":[11,0,142,0],
-"structspa__audio__info__aac.html#ad93ec0c832f6ed449d9e073068e221d1":[11,0,142,3],
-"structspa__audio__info__alac.html":[11,0,143],
-"structspa__audio__info__alac.html#a93d94a062b877bdb495bd1b07364f05d":[11,0,143,0],
-"structspa__audio__info__alac.html#afd38ff2d76cd8078e80f8955dc23da19":[11,0,143,1],
-"structspa__audio__info__amr.html":[11,0,144],
-"structspa__audio__info__amr.html#a1b1d2870fa166b3de6bf2f5b1b45a05d":[11,0,144,1],
-"structspa__audio__info__amr.html#a42ebba3d8e2cdd474ef49fb4c4c6b0f4":[11,0,144,2],
-"structspa__audio__info__amr.html#ac715c7089e6ff2b562a3762bd46136cb":[11,0,144,0],
-"structspa__audio__info__ape.html":[11,0,145],
-"structspa__audio__info__ape.html#a72509a439dfbe203c6c3653bed2153ed":[11,0,145,0],
-"structspa__audio__info__ape.html#a82e8f9bb5e9bd7bd014a92709a06b9f9":[11,0,145,1],
+"structspa__audio__info__aac.html":[11,0,143],
+"structspa__audio__info__aac.html#a16974760cfa2cbe91398d01fb7f4b947":[11,0,143,1],
+"structspa__audio__info__aac.html#a3b08334e341344e0035a7ee94a5c87a2":[11,0,143,2],
+"structspa__audio__info__aac.html#ab29a8d8e1cba013ab5008404ba2836ea":[11,0,143,0],
+"structspa__audio__info__aac.html#ad93ec0c832f6ed449d9e073068e221d1":[11,0,143,3],
+"structspa__audio__info__alac.html":[11,0,144],
+"structspa__audio__info__alac.html#a93d94a062b877bdb495bd1b07364f05d":[11,0,144,0],
+"structspa__audio__info__alac.html#afd38ff2d76cd8078e80f8955dc23da19":[11,0,144,1],
+"structspa__audio__info__amr.html":[11,0,145],
+"structspa__audio__info__amr.html#a1b1d2870fa166b3de6bf2f5b1b45a05d":[11,0,145,1],
+"structspa__audio__info__amr.html#a42ebba3d8e2cdd474ef49fb4c4c6b0f4":[11,0,145,2],
+"structspa__audio__info__amr.html#ac715c7089e6ff2b562a3762bd46136cb":[11,0,145,0],
+"structspa__audio__info__ape.html":[11,0,146],
+"structspa__audio__info__ape.html#a72509a439dfbe203c6c3653bed2153ed":[11,0,146,0],
+"structspa__audio__info__ape.html#a82e8f9bb5e9bd7bd014a92709a06b9f9":[11,0,146,1],
 "structspa__audio__info__dsd.html":[10,8,7,33],
 "structspa__audio__info__dsd.html#a4f11fce0402edcbe61f0b35f27396ac9":[10,8,7,33,5],
 "structspa__audio__info__dsd.html#a563add98a612fe3617a58e2cb1a703bc":[10,8,7,33,4],
@@ -46,39 +74,39 @@ var NAVTREEINDEX20 =
 "structspa__audio__info__dsd.html#a72a8060d8747abb6e380e0dc0261157e":[10,8,7,33,3],
 "structspa__audio__info__dsd.html#a902dd094aab140dc3500a3a36ef967da":[10,8,7,33,2],
 "structspa__audio__info__dsd.html#a9f7ed724310d9b5a2c95607399fe3a34":[10,8,7,33,1],
-"structspa__audio__info__dsp.html":[11,0,147],
-"structspa__audio__info__dsp.html#ab59df8be3387df377c8b698346aa234f":[11,0,147,0],
-"structspa__audio__info__flac.html":[11,0,148],
-"structspa__audio__info__flac.html#a3351a0cbf04538db70fac13cd630e79e":[11,0,148,1],
-"structspa__audio__info__flac.html#a9be31890542f5995b7bbe493cd29f688":[11,0,148,0],
+"structspa__audio__info__dsp.html":[11,0,148],
+"structspa__audio__info__dsp.html#ab59df8be3387df377c8b698346aa234f":[11,0,148,0],
+"structspa__audio__info__flac.html":[11,0,149],
+"structspa__audio__info__flac.html#a3351a0cbf04538db70fac13cd630e79e":[11,0,149,1],
+"structspa__audio__info__flac.html#a9be31890542f5995b7bbe493cd29f688":[11,0,149,0],
 "structspa__audio__info__iec958.html":[10,8,7,35],
 "structspa__audio__info__iec958.html#ab4797480f2e4e7f25d19a0a42c748eac":[10,8,7,35,1],
 "structspa__audio__info__iec958.html#adc76e7bde0fc3d66ffa5a8442c3b1409":[10,8,7,35,0],
 "structspa__audio__info__iec958.html#af028b6675757cd4504ad1b11a2e746c7":[10,8,7,35,2],
-"structspa__audio__info__mp3.html":[11,0,150],
-"structspa__audio__info__mp3.html#a2066d86c3d391a097c57441f8c391234":[11,0,150,0],
-"structspa__audio__info__mp3.html#a9eab81f1ef553124803e7563d7ffce93":[11,0,150,1],
-"structspa__audio__info__opus.html":[11,0,151],
-"structspa__audio__info__opus.html#ab354cfeab8ed9e4561332f86f77f5397":[11,0,151,1],
-"structspa__audio__info__opus.html#abf65d8f7d0877d50068bb68cff1f3e44":[11,0,151,0],
-"structspa__audio__info__ra.html":[11,0,152],
-"structspa__audio__info__ra.html#a281cd0f54656e1ccfda03854e5d36ce2":[11,0,152,1],
-"structspa__audio__info__ra.html#aa5374f33cf4a773ca3bb779d3e199fc9":[11,0,152,0],
+"structspa__audio__info__mp3.html":[11,0,151],
+"structspa__audio__info__mp3.html#a2066d86c3d391a097c57441f8c391234":[11,0,151,0],
+"structspa__audio__info__mp3.html#a9eab81f1ef553124803e7563d7ffce93":[11,0,151,1],
+"structspa__audio__info__opus.html":[11,0,152],
+"structspa__audio__info__opus.html#ab354cfeab8ed9e4561332f86f77f5397":[11,0,152,1],
+"structspa__audio__info__opus.html#abf65d8f7d0877d50068bb68cff1f3e44":[11,0,152,0],
+"structspa__audio__info__ra.html":[11,0,153],
+"structspa__audio__info__ra.html#a281cd0f54656e1ccfda03854e5d36ce2":[11,0,153,1],
+"structspa__audio__info__ra.html#aa5374f33cf4a773ca3bb779d3e199fc9":[11,0,153,0],
 "structspa__audio__info__raw.html":[10,8,7,37],
 "structspa__audio__info__raw.html#a542692f9d3518632e37ea575d13ca149":[10,8,7,37,0],
 "structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952":[10,8,7,37,3],
 "structspa__audio__info__raw.html#a696f18b889bb8a5496e16dd48f7d8e01":[10,8,7,37,1],
 "structspa__audio__info__raw.html#ac21ae45356ef4e1dbfde141937fde9c5":[10,8,7,37,4],
 "structspa__audio__info__raw.html#ae7e501bbfbef2cd75f3ae0f13719652c":[10,8,7,37,2],
-"structspa__audio__info__vorbis.html":[11,0,154],
-"structspa__audio__info__vorbis.html#a7614ad24e4491223d0d44c1931c3089b":[11,0,154,0],
-"structspa__audio__info__vorbis.html#afec5882d3af8e9d177b4b0771c176046":[11,0,154,1],
-"structspa__audio__info__wma.html":[11,0,155],
-"structspa__audio__info__wma.html#a08102a7049195a3a9f5b734a6b8f7be5":[11,0,155,1],
-"structspa__audio__info__wma.html#a0bf6e6bad02abf194f2d65b5b458e7ba":[11,0,155,4],
-"structspa__audio__info__wma.html#a328501d7905f732937932d3731916a55":[11,0,155,3],
-"structspa__audio__info__wma.html#a46f090f295f02f54aaa427abb93d44e2":[11,0,155,2],
-"structspa__audio__info__wma.html#ad572e9079c943a87b18d96060ced5af4":[11,0,155,0],
+"structspa__audio__info__vorbis.html":[11,0,155],
+"structspa__audio__info__vorbis.html#a7614ad24e4491223d0d44c1931c3089b":[11,0,155,0],
+"structspa__audio__info__vorbis.html#afec5882d3af8e9d177b4b0771c176046":[11,0,155,1],
+"structspa__audio__info__wma.html":[11,0,156],
+"structspa__audio__info__wma.html#a08102a7049195a3a9f5b734a6b8f7be5":[11,0,156,1],
+"structspa__audio__info__wma.html#a0bf6e6bad02abf194f2d65b5b458e7ba":[11,0,156,4],
+"structspa__audio__info__wma.html#a328501d7905f732937932d3731916a55":[11,0,156,3],
+"structspa__audio__info__wma.html#a46f090f295f02f54aaa427abb93d44e2":[11,0,156,2],
+"structspa__audio__info__wma.html#ad572e9079c943a87b18d96060ced5af4":[11,0,156,0],
 "structspa__audio__layout__info.html":[10,8,7,36],
 "structspa__audio__layout__info.html#a939d325d78f6c2cb4492fda99fe3efd0":[10,8,7,36,1],
 "structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[10,8,7,36,0],
@@ -188,14 +216,14 @@ var NAVTREEINDEX20 =
 "structspa__dict__item.html":[10,8,8,2,1],
 "structspa__dict__item.html#a16dc8153e2ea77c9c82380456734478a":[10,8,8,2,1,0],
 "structspa__dict__item.html#af08479e3ff870039be002b436a02457d":[10,8,8,2,1,1],
-"structspa__dll.html":[11,0,179],
-"structspa__dll.html#a6e71bca8352ac6213b6d26c22732c9a1":[11,0,179,2],
-"structspa__dll.html#a7b2d7a0adb6cdc3680db685fef886d78":[11,0,179,1],
-"structspa__dll.html#a90a86177cee5a8c972d4a2825244d3de":[11,0,179,6],
-"structspa__dll.html#aa109171408f82fa3f287b70e2396ba42":[11,0,179,3],
-"structspa__dll.html#aa99d781b6e4c1133db7bef843fc4a21a":[11,0,179,4],
-"structspa__dll.html#ac3de731c327763f69c44e98224ee1068":[11,0,179,0],
-"structspa__dll.html#ae1e3a33d3f38548692173d283b613574":[11,0,179,5],
+"structspa__dll.html":[11,0,180],
+"structspa__dll.html#a6e71bca8352ac6213b6d26c22732c9a1":[11,0,180,2],
+"structspa__dll.html#a7b2d7a0adb6cdc3680db685fef886d78":[11,0,180,1],
+"structspa__dll.html#a90a86177cee5a8c972d4a2825244d3de":[11,0,180,6],
+"structspa__dll.html#aa109171408f82fa3f287b70e2396ba42":[11,0,180,3],
+"structspa__dll.html#aa99d781b6e4c1133db7bef843fc4a21a":[11,0,180,4],
+"structspa__dll.html#ac3de731c327763f69c44e98224ee1068":[11,0,180,0],
+"structspa__dll.html#ae1e3a33d3f38548692173d283b613574":[11,0,180,5],
 "structspa__event.html":[10,8,0,15],
 "structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb":[10,8,0,15,1],
 "structspa__event.html#a2411141eed88d3587687a8d86c99d488":[10,8,0,15,0],
@@ -221,33 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__graph__node.html#a7a4bea046f4d6a88d97e12a5297ed740":[10,8,5,5,1],
 "structspa__graph__node.html#ab16592a35d02f827271786b49110341c":[10,8,5,5,7],
 "structspa__graph__node.html#acbee04440eefb9b0a77f69ff1876dbc0":[10,8,5,5,6],
-"structspa__graph__node.html#acfb4e7658140701927336dee05ed1948":[10,8,5,5,3],
-"structspa__graph__node.html#ada29bc9109cd890c74cfba630989b76c":[10,8,5,5,5],
-"structspa__graph__node.html#aec1169015c1d7a4aaea10d5f4946f7d4":[10,8,5,5,2],
-"structspa__graph__node.html#af4ae9586aa3d544a48414987f1839a67":[10,8,5,5,9],
-"structspa__graph__node__callbacks.html":[10,8,5,4],
-"structspa__graph__node__callbacks.html#a9c7b2744d4983173d88469654e626375":[10,8,5,4,1],
-"structspa__graph__node__callbacks.html#abc2bcb2b88b65f3eabe0e13d5d73f4e8":[10,8,5,4,2],
-"structspa__graph__node__callbacks.html#acbbdda8c4d517ce24ee12cad1c4e60ec":[10,8,5,4,0],
-"structspa__graph__port.html":[10,8,5,6],
-"structspa__graph__port.html#a2010d31b7d56fef0f5a8eeb4188e7ff6":[10,8,5,6,1],
-"structspa__graph__port.html#a6a077a5cc2c1115b43d05208bb072208":[10,8,5,6,3],
-"structspa__graph__port.html#a7139cc16698356c2fc915149d45a741f":[10,8,5,6,5],
-"structspa__graph__port.html#a8ee1612c0aaef539c9270761f3d6d8b6":[10,8,5,6,4],
-"structspa__graph__port.html#ac60bcc3482ad354bc5ae32d3cade3a02":[10,8,5,6,2],
-"structspa__graph__port.html#af25d08a94327c7642abd9d22c1f00dee":[10,8,5,6,0],
-"structspa__graph__state.html":[10,8,5,1],
-"structspa__graph__state.html#a8f3cf9778a95b2717a5a6ac0d5b55bb9":[10,8,5,1,2],
-"structspa__graph__state.html#a98a2cfe5aa419430cefaf19e3836ce40":[10,8,5,1,1],
-"structspa__graph__state.html#ade14580f5dc43afc10b857d4233d3f99":[10,8,5,1,0],
-"structspa__handle.html":[10,8,9,5,1],
-"structspa__handle.html#a28e6fe4b4f4bdd29f007a1339cbe972a":[10,8,9,5,1,1],
-"structspa__handle.html#aaef038ef76a15ddaf5833510535716b4":[10,8,9,5,1,2],
-"structspa__handle.html#aaf5d3406480eab83a92db807bc2154c5":[10,8,9,5,1,0],
-"structspa__handle__factory.html":[10,8,9,5,4],
-"structspa__handle__factory.html#a00264d237fb8d45b1878d8ea32fbb5b2":[10,8,9,5,4,4],
-"structspa__handle__factory.html#a528ffc68aa9b406e094c04bba09bbc10":[10,8,9,5,4,0],
-"structspa__handle__factory.html#a6edd8af903eeb185389da41ee945158f":[10,8,9,5,4,1],
-"structspa__handle__factory.html#aa48d0b857861f618011a9f4a89435484":[10,8,9,5,4,2],
-"structspa__handle__factory.html#ad9e9ca49d03aed627c1c1ac5db5266d7":[10,8,9,5,4,3]
+"structspa__graph__node.html#acfb4e7658140701927336dee05ed1948":[10,8,5,5,3]
 };
