@@ -1,5 +1,17 @@
 var NAVTREEINDEX7 =
 {
+"group__spa__cpu.html#ga863ee498bc3630a98ee12fe569a9dc30":[10,8,9,0,10],
+"group__spa__cpu.html#ga898241b82efab179bd63ebea6c6e7d32":[10,8,9,0,39],
+"group__spa__cpu.html#ga8a8442eb592a7cb99c969edd45b55b01":[10,8,9,0,36],
+"group__spa__cpu.html#ga8e4904a089d0f96603ef7a7fb87c378f":[10,8,9,0,19],
+"group__spa__cpu.html#ga8fb893812b3fb95768f2c85419463530":[10,8,9,0,62],
+"group__spa__cpu.html#ga94394c9aeeccf55a71dc8b786e674f40":[10,8,9,0,31],
+"group__spa__cpu.html#ga9f6412675e3d21a115ea214c1f720c01":[10,8,9,0,22],
+"group__spa__cpu.html#gaa186cfc60f43633587d086ba0f85941e":[10,8,9,0,3],
+"group__spa__cpu.html#gaa6d2558bc9c0504d658b87a9c333df33":[10,8,9,0,23],
+"group__spa__cpu.html#gaa79cbeabcefc6e5e4de4dced2461bafc":[10,8,9,0,21],
+"group__spa__cpu.html#gaa96fa19763cd1ed32cb5cf4dba70ad31":[10,8,9,0,35],
+"group__spa__cpu.html#gaab2a78075bf054d09f7e950150278b8b":[10,8,9,0,47],
 "group__spa__cpu.html#gaabed68d3b3d4db276c57891df69fbc93":[10,8,9,0,49],
 "group__spa__cpu.html#gab0e2f34eb8b3aa5f1eb74be67decae9a":[10,8,9,0,6],
 "group__spa__cpu.html#gabb4142740151dfe408cb49f344da06de":[10,8,9,0,43],
@@ -78,27 +90,27 @@ var NAVTREEINDEX7 =
 "group__spa__device.html#ga0ecfe713ec074a6d73cb8abd986f9ffd":[10,8,4,17],
 "group__spa__device.html#ga0ede742404df36a3f585ac584b76c007":[10,8,4,10],
 "group__spa__device.html#ga10fabcc92b08aee36d96870d881a5fa2":[10,8,4,50],
-"group__spa__device.html#ga1c95c5a55d127c4d928fd30dc0979a7c":[10,8,4,73],
+"group__spa__device.html#ga1c95c5a55d127c4d928fd30dc0979a7c":[10,8,4,74],
 "group__spa__device.html#ga1ff1ff0222897525ba3799d0e63ff7c7":[10,8,4,26],
-"group__spa__device.html#ga2bd95e2462bc66fff656e3ce1154a039":[10,8,4,72],
+"group__spa__device.html#ga2bd95e2462bc66fff656e3ce1154a039":[10,8,4,73],
 "group__spa__device.html#ga301b070b032f9f696a9bd34e2be08dd1":[10,8,4,20],
 "group__spa__device.html#ga31494fdbe7a296b2ab2a12981c88fc4f":[10,8,4,59],
 "group__spa__device.html#ga3342deed3d0ba9393a405a51af000c74":[10,8,4,38],
-"group__spa__device.html#ga339438a47cb30c831971c25d7494f2a5":[10,8,4,75],
-"group__spa__device.html#ga348873b3533acd66e912773ad9ae740d":[10,8,4,69],
+"group__spa__device.html#ga339438a47cb30c831971c25d7494f2a5":[10,8,4,76],
+"group__spa__device.html#ga348873b3533acd66e912773ad9ae740d":[10,8,4,70],
 "group__spa__device.html#ga443f624a82ee2787358e46f969904f9d":[10,8,4,48],
 "group__spa__device.html#ga480dd7732417339fcea900102938e822":[10,8,4,28],
 "group__spa__device.html#ga4bf09e2b53a707f74b1cf487d1bda6af":[10,8,4,25],
 "group__spa__device.html#ga4cde26af07d8cce0804ddb9de69070a5":[10,8,4,14],
-"group__spa__device.html#ga51368ce31a7859fad5132fcc8595d664":[10,8,4,64],
+"group__spa__device.html#ga51368ce31a7859fad5132fcc8595d664":[10,8,4,65],
 "group__spa__device.html#ga52be50ca0f60cf6fffe0a064be606cf2":[10,8,4,24],
 "group__spa__device.html#ga5fc03e022b6b34a95c40b992b46210b3":[10,8,4,55],
 "group__spa__device.html#ga64af18e863a2a13cfe4e9ac71adb5b20":[10,8,4,31],
-"group__spa__device.html#ga6573dc405f256f96d9ec6b6518c5c6d8":[10,8,4,71],
-"group__spa__device.html#ga65e21b7134e493124a67e4c582564c29":[10,8,4,68],
-"group__spa__device.html#ga6d0493b863780697cf564ff4ae297191":[10,8,4,80],
+"group__spa__device.html#ga6573dc405f256f96d9ec6b6518c5c6d8":[10,8,4,72],
+"group__spa__device.html#ga65e21b7134e493124a67e4c582564c29":[10,8,4,69],
+"group__spa__device.html#ga6d0493b863780697cf564ff4ae297191":[10,8,4,81],
 "group__spa__device.html#ga725ef202231224d45f0297aa2c6e84f1":[10,8,4,57],
-"group__spa__device.html#ga756d90f78ac51e42bcfd0405b40e2fb9":[10,8,4,74],
+"group__spa__device.html#ga756d90f78ac51e42bcfd0405b40e2fb9":[10,8,4,75],
 "group__spa__device.html#ga79781ecdf5018c8f19098debbb40b5d0":[10,8,4,41],
 "group__spa__device.html#ga79f9c18c7d8738f0cafe71f1ceb66f64":[10,8,4,37],
 "group__spa__device.html#ga7a2ffda68c8091296ccbe152e3491a5f":[10,8,4,60],
@@ -107,24 +119,25 @@ var NAVTREEINDEX7 =
 "group__spa__device.html#ga83ed2e7e51ac9f7bc92fa0330b55eb86":[10,8,4,36],
 "group__spa__device.html#ga85d9cdd3fe854db0c1cda7b46e5a1d34":[10,8,4,45],
 "group__spa__device.html#ga8add515ce73b066a62ccd45232a1b968":[10,8,4,62],
-"group__spa__device.html#ga8d73dce5d09986b12b102917fb79278b":[10,8,4,67],
+"group__spa__device.html#ga8d73dce5d09986b12b102917fb79278b":[10,8,4,68],
 "group__spa__device.html#ga9041192b59420c24635c77848b5ab7d5":[10,8,4,11],
 "group__spa__device.html#ga951b6e27cbc5b868672a87b8c9b5d818":[10,8,4,43],
 "group__spa__device.html#ga956329c75f9076a9de5a2ee8f9cefed3":[10,8,4,30],
 "group__spa__device.html#ga956f53165732be66eff3cd772e80b7cf":[10,8,4,46],
-"group__spa__device.html#ga976176b17916248c604ae02498d9f648":[10,8,4,65],
+"group__spa__device.html#ga976176b17916248c604ae02498d9f648":[10,8,4,66],
 "group__spa__device.html#ga9bf1b22af1de0ff91ebb45df40d82645":[10,8,4,34],
 "group__spa__device.html#ga9f19955c5b6a77028eb697a130a5f22e":[10,8,4,47],
 "group__spa__device.html#ga9fc516e68fefb9e3c7f08a5fa4ac8242":[10,8,4,22],
 "group__spa__device.html#gaa6141368f70a58863efc5494673903ba":[10,8,4,33],
+"group__spa__device.html#gaa88a2b38462288f4b31b71bf8d6f480a":[10,8,4,64],
 "group__spa__device.html#gaa8e69a2fae59e8d6d1d1da5f0660cbc3":[10,8,4,13],
 "group__spa__device.html#gab347a871f54232e2f8362c60fd893128":[10,8,4,21],
 "group__spa__device.html#gab68858d85274969e6f2502e95547f429":[10,8,4,51],
 "group__spa__device.html#gab7ccc98f93f0269396bcbcd3efd1fdb8":[10,8,4,18],
-"group__spa__device.html#gabcb2230b6ab2020ceef73fad9e1fd7dc":[10,8,4,70],
-"group__spa__device.html#gac59665317b0bc49197df89771abf6499":[10,8,4,66],
-"group__spa__device.html#gac5d87bd2bc51abe0c370198371428f6f":[10,8,4,78],
-"group__spa__device.html#gac7701f46169fcc7a70be0f7167b97cff":[10,8,4,76],
+"group__spa__device.html#gabcb2230b6ab2020ceef73fad9e1fd7dc":[10,8,4,71],
+"group__spa__device.html#gac59665317b0bc49197df89771abf6499":[10,8,4,67],
+"group__spa__device.html#gac5d87bd2bc51abe0c370198371428f6f":[10,8,4,79],
+"group__spa__device.html#gac7701f46169fcc7a70be0f7167b97cff":[10,8,4,77],
 "group__spa__device.html#gacb844f03c2733e1f62385bf0633aad06":[10,8,4,49],
 "group__spa__device.html#gacbbe2dd80be7dac7ffb2e228a244339c":[10,8,4,27],
 "group__spa__device.html#gacbe7c7131058a38cd357c7028387a1ff":[10,8,4,23],
@@ -133,7 +146,7 @@ var NAVTREEINDEX7 =
 "group__spa__device.html#gad97ce15937ee02d483156a0937260f76":[10,8,4,56],
 "group__spa__device.html#gadef390bb7a8fbcfca7bf01639ed6b9e6":[10,8,4,40],
 "group__spa__device.html#gae011d2c6dce34040bfe95c9a5b0a8fc4":[10,8,4,58],
-"group__spa__device.html#gae3d33bd6e79f4fdb1a19402def48e044":[10,8,4,79],
+"group__spa__device.html#gae3d33bd6e79f4fdb1a19402def48e044":[10,8,4,80],
 "group__spa__device.html#gae4f6fcd5af1159ca52a6e032174e0555":[10,8,4,39],
 "group__spa__device.html#gae5a43b17b5a707684dfedb342082ef58":[10,8,4,35],
 "group__spa__device.html#gae5c1deaf4987a5c43c1462e46f18b19b":[10,8,4,19],
@@ -142,11 +155,11 @@ var NAVTREEINDEX7 =
 "group__spa__device.html#gaee6259c06260e89b9c7e6186b9975998":[10,8,4,12],
 "group__spa__device.html#gaf14cd663ab18bce958a27cbfa145a79a":[10,8,4,15],
 "group__spa__device.html#gaf1cc3abc675d1f7369ea994f09fb86b7":[10,8,4,53],
-"group__spa__device.html#gafaeb4b272c4322e31836412c4a0c2f74":[10,8,4,77],
-"group__spa__device.html#gga339438a47cb30c831971c25d7494f2a5aceb0a1999207e2a7b194acb0bed873d2":[10,8,4,75,0],
-"group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffa53397e3b7eb932bb53d11a9a56d63ba9":[10,8,4,76,1],
-"group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffaaa0c9d6240dfd91934eaaeea8172f575":[10,8,4,76,2],
-"group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffabdb537e7cf8f7312e5c553dc06428a14":[10,8,4,76,0],
+"group__spa__device.html#gafaeb4b272c4322e31836412c4a0c2f74":[10,8,4,78],
+"group__spa__device.html#gga339438a47cb30c831971c25d7494f2a5aceb0a1999207e2a7b194acb0bed873d2":[10,8,4,76,0],
+"group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffa53397e3b7eb932bb53d11a9a56d63ba9":[10,8,4,77,1],
+"group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffaaa0c9d6240dfd91934eaaeea8172f575":[10,8,4,77,2],
+"group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffabdb537e7cf8f7312e5c553dc06428a14":[10,8,4,77,0],
 "group__spa__dict.html":[10,8,8,2],
 "group__spa__dict.html#ga2f4c23f6a5dd5c9eb93cfeccb8211901":[10,8,8,2,3],
 "group__spa__dict.html#ga892ec66ef5891b9d84e403ab815356bf":[10,8,8,2,6],
@@ -181,7 +194,6 @@ var NAVTREEINDEX7 =
 "group__spa__graph.html#ga85dfce75df6a24fc0a29945ab03b1c86":[10,8,5,7],
 "group__spa__graph.html#ga8845237cef2bd684bb2f0de82f8f1019":[10,8,5,29],
 "group__spa__graph.html#ga8ed30e4e1d124815203cfe5ba275b460":[10,8,5,31],
-"group__spa__graph.html#ga90b3032bbb5d2b78525f8ffde804308c":[10,8,5,9],
 "group__spa__graph.html#gaa1eec75ae44307a384b5f2d4d869bbc6":[10,8,5,20],
 "group__spa__graph.html#gaac674e745b114565e44f5a451df13f52":[10,8,5,33],
 "group__spa__graph.html#gaad5ba578c8601c9239c455b0dc2c68c7":[10,8,5,11],
@@ -189,6 +201,7 @@ var NAVTREEINDEX7 =
 "group__spa__graph.html#gadba31399bd4eccf65b5dbc8bcf378065":[10,8,5,23],
 "group__spa__graph.html#gaeea00171bcd084512a1e819c84247e27":[10,8,5,19],
 "group__spa__graph.html#gaf3a2fc5db0af85206c694318944beef2":[10,8,5,10],
+"group__spa__graph.html#gaf4ffa38ece7913a1eb5f4e6a65275122":[10,8,5,9],
 "group__spa__graph.html#gafae076c37db9c913ce0afb6cd285c6ff":[10,8,5,34],
 "group__spa__handle.html":[10,8,9,5],
 "group__spa__handle.html#ga002303dd0962faff5b0f15ea48488635":[10,8,9,5,17],
@@ -230,24 +243,11 @@ var NAVTREEINDEX7 =
 "group__spa__i18n.html#gaf3aa0f8921abf9d572c9fde4a9d0825d":[10,8,9,2,5],
 "group__spa__i18n.html#gafe48fd94d55ba3db8f10fb1550ec79c8":[10,8,9,2,6],
 "group__spa__interfaces.html":[10,8,8,5],
-"group__spa__interfaces.html#ga0b43b5a0ee8aa8f305d0c9971716e5b0":[10,8,8,5,14],
-"group__spa__interfaces.html#ga1566a7843972b177af627e6e16b86c26":[10,8,8,5,11],
-"group__spa__interfaces.html#ga1facc1b12f5dfb7e3362e9f1a6d3cb6c":[10,8,8,5,13],
-"group__spa__interfaces.html#ga5f51d2f3b4df5eb44fa6163ba3958f5d":[10,8,8,5,7],
-"group__spa__interfaces.html#ga6492da0e834e92dbbcef7dd3026ce04f":[10,8,8,5,9],
-"group__spa__interfaces.html#ga7cd31fca0faa447261fb4425d8036bb5":[10,8,8,5,5],
-"group__spa__interfaces.html#ga7eadf4e30be75d856d81c9b0d818b0e1":[10,8,8,5,3],
-"group__spa__interfaces.html#ga8ba5c01fe17d8a199516e2d87e59c025":[10,8,8,5,12],
-"group__spa__interfaces.html#gab3415032c65751a4b16279a6167f5972":[10,8,8,5,8],
-"group__spa__interfaces.html#gac11e7999a90fa354ef765abf8a6f9696":[10,8,8,5,10],
-"group__spa__interfaces.html#gaf9eef5cf634711b4de82fc5f9e3802ee":[10,8,8,5,6],
-"group__spa__interfaces.html#gafbe7e2c178c8649d89fe3d6cfcb74c65":[10,8,8,5,4],
-"group__spa__json.html":[10,8,8,6],
-"group__spa__json.html#ga04a8b54928642e8bc49077d7f26e57a5":[10,8,8,6,10],
-"group__spa__json.html#ga07e1f5cda4b1894f6165805159d11faa":[10,8,8,6,28],
-"group__spa__json.html#ga0d0d13b703fb3bf42b6a96b11973767a":[10,8,8,6,4],
-"group__spa__json.html#ga16c676cb24334b96a9e1eaf0d73ec39f":[10,8,8,6,17],
-"group__spa__json.html#ga255f1962c8cb52c861c197533693732c":[10,8,8,6,16],
-"group__spa__json.html#ga2b070aa36336cbe95ffe1871672ecd70":[10,8,8,6,23],
-"group__spa__json.html#ga2fe3d2f299b7227b36c93c84c0117f96":[10,8,8,6,30]
+"group__spa__interfaces.html#ga0b43b5a0ee8aa8f305d0c9971716e5b0":[10,8,8,5,17],
+"group__spa__interfaces.html#ga12d9c46094ccfe8448e2d592cc8f457b":[10,8,8,5,18],
+"group__spa__interfaces.html#ga1566a7843972b177af627e6e16b86c26":[10,8,8,5,13],
+"group__spa__interfaces.html#ga1facc1b12f5dfb7e3362e9f1a6d3cb6c":[10,8,8,5,15],
+"group__spa__interfaces.html#ga333235e7b2636c920cfa766481e59729":[10,8,8,5,16],
+"group__spa__interfaces.html#ga48dc1c688fd324d08a3eed9684abf41a":[10,8,8,5,8],
+"group__spa__interfaces.html#ga5f51d2f3b4df5eb44fa6163ba3958f5d":[10,8,8,5,7]
 };
