@@ -7,13 +7,19 @@ var page_pipewire_modules =
     [ "PipeWire Module: Client Node", "page_module_client_node.html", null ],
     [ "PipeWire Module: Combine Stream", "page_module_combine_stream.html", null ],
     [ "PipeWire Module: Echo Cancel", "page_module_echo_cancel.html", null ],
+    [ "PipeWire Module: Example Filter", "page_module_example_filter.html", null ],
     [ "PipeWire Module: Example Sink", "page_module_example_sink.html", null ],
     [ "PipeWire Module: Example Source", "page_module_example_source.html", null ],
     [ "PipeWire Module: Fallback Sink", "page_module_fallback_sink.html", null ],
+    [ "PipeWire Module: FFADO firewire audio driver", "page_module_ffado_driver.html", null ],
     [ "PipeWire Module: Filter-Chain", "page_module_filter_chain.html", null ],
+    [ "PipeWire Module: JACK DBus detect", "page_module_jackdbus_detect.html", null ],
+    [ "PipeWire Module: JACK Tunnel", "page_module_jack_tunnel.html", null ],
     [ "PipeWire Module: Link Factory", "page_module_link_factory.html", null ],
     [ "PipeWire Module: Loopback", "page_module_loopback.html", null ],
     [ "PipeWire Module: Metadata", "page_module_metadata.html", null ],
+    [ "PipeWire Module: Netjack2 driver", "page_module_netjack2_driver.html", null ],
+    [ "PipeWire Module: Netjack2 manager", "page_module_netjack2_manager.html", null ],
     [ "PipeWire Module: Unix Pipe Tunnel", "page_module_pipe_tunnel.html", null ],
     [ "PipeWire Module: Portal", "page_module_portal.html", null ],
     [ "PipeWire Module: Profiler", "page_module_profiler.html", null ],
@@ -25,7 +31,7 @@ var page_pipewire_modules =
     [ "PipeWire Module: RAOP Discover", "page_module_raop_discover.html", null ],
     [ "PipeWire Module: ROC sink", "page_module_roc_sink.html", null ],
     [ "PipeWire Module: ROC source", "page_module_roc_source.html", null ],
-    [ "PipeWire Module: Announce and create RTP streams", "page_module_rtp_sap.html", null ],
+    [ "PipeWire Module: SAP Announce and create RTP streams", "page_module_rtp_sap.html", null ],
     [ "PipeWire Module: RTP sink", "page_module_rtp_sink.html", null ],
     [ "PipeWire Module: RTP source", "page_module_rtp_source.html", null ],
     [ "PipeWire Module: RTP session", "page_module_rtp_session.html", null ],
